use maud::{PreEscaped, html};

use crate::ui::{UIWidget, color::UIColor};

use super::ColorCircle;

#[allow(non_snake_case)]
pub fn Indicator<C: UIColor + 'static>(color: C) -> PreEscaped<String> {
    html! {
        span class=(format!("flex w-3 h-3 me-3 bg-{} rounded-full", color.color_class())) {};
    }
}

#[allow(non_snake_case)]
pub fn IndicatorLegend<C: UIColor + 'static>(color: C, legend: &str) -> PreEscaped<String> {
    html! {
        span class="flex items-center text-sm font-medium text-gray-900 dark:text-white me-3" {
            span class=(format!("flex w-2.5 h-2.5 bg-{} rounded-full me-1.5 shrink-0", color.color_class())) {};
            (legend)
        };
    }
}

#[allow(non_snake_case)]
pub fn NumberIndicator<T: UIWidget + 'static>(on: T, amount: u32) -> PreEscaped<String> {
    html! {
            div class="relative items-center max-w-fit" {
    (on)
      div class="absolute inline-flex items-center justify-center px-2 text-xs font-bold text-white bg-red-500 border-2 border-white rounded-full -top-2 -end-2 dark:border-gray-900" { (amount) };
        }
        }
}

#[allow(non_snake_case)]
pub fn BadgeIndicator<C: UIColor + 'static + ColorCircle>(
    color: C,
    dark_color: C,
    txt: &str,
) -> PreEscaped<String> {
    // BG -100
    let bg_color = color.color_class();
    // Text -800
    let text_color = color.next().next().next().next().next().next().next();
    let text_color = text_color.color_class();
    // Dark BG -900
    let dark_bg = dark_color.color_class();
    // Dark Text -300
    let dark_text = dark_color
        .previous()
        .previous()
        .previous()
        .previous()
        .previous()
        .previous();
    let dark_text = dark_text.color_class();
    // Indicator -500
    let indicator_color = color.middle();
    let indicator_color = indicator_color.color_class();

    html! {
        span
        class=(format!("inline-flex items-center bg-{bg_color} text-{text_color} text-xs font-medium px-2.5 py-0.5 rounded-full dark:bg-{dark_bg} dark:text-{dark_text}")) {
            span class=(format!("w-2 h-2 me-1 bg-{indicator_color} rounded-full")) {};
            (txt)
        };
    }
}
